==> cndrvcups-lb-3.10-1.tar.gz: cndrvcups-lb-3.10/cngplp/gladestr.h <==
/* xgettext:no-c-format */
char *s = N_("(0 to 200)%");
char *s = N_("(1 to 10000)");
char *s = N_("(1 to 9999)");
char *s = N_("(1 to 9999999)");
char *s = N_("(Max. 32 characters)");
char *s = N_("*");
char *s = N_("0 to 99");
char *s = N_("Adjust Toner Volume Used for Color Printing:");
char *s = N_("Adjust Trim Width by");
char *s = N_("Advanced Settings");
char *s = N_("Advanced Settings...");
char *s = N_("Advanced Smoothing:");
char *s = N_("Allow Password Setting");
char *s = N_("Apply Device Settings");
char *s = N_("Automatic Correction");
char *s = N_("B & W Halftones:");
char *s = N_("Back Side");
char *s = N_("Banner");
char *s = N_("Binding Location:");
char *s = N_("Book Opening:");
char *s = N_("Booklet...");
char *s = N_("Brightness and Gamma");
char *s = N_("Brightness:");
char *s = N_("Cancel");
char *s = N_("Color Halftones:");
char *s = N_("Color Mode:");
char *s = N_("Color to Use with Black:");
char *s = N_("Copy Set Numbering");
char *s = N_("Correction Width:");
char *s = N_("Data Name");
char *s = N_("Dept. ID Management Authentication:");
char *s = N_("Detailed Settings for Booklet");
char *s = N_("Device Setting ");
char *s = N_("Device Settings");
char *s = N_("Disable Job Accounting When B&W Print");
char *s = N_("Displacement Correction Method");
char *s = N_("Document Insertion Unit");
char *s = N_("Document Name:");
char *s = N_("Draft Mode:");
char *s = N_("End:");
char *s = N_("Enter Name");
char *s = N_("Face Up/Face Down:");
char *s = N_("Feed A5 from Short Edge:");
char *s = N_("Finishing");
char *s = N_("Finishing Details");
char *s = N_("Finishing Details...");
char *s = N_("Finishing:");
char *s = N_("Fold Details:");
char *s = N_("Fold:");
char *s = N_("Front Side");
char *s = N_("Front/Back Cover Settings");
char *s = N_("Front/Back Cover Settings...");
char *s = N_("Gamma:");
char *s = N_("General");
char *s = N_("Glossy Plain Paper Processing:");
char *s = N_("Gutter Settings");
char *s = N_("Gutter...");
char *s = N_("Gutter:");
char *s = N_("Hole Punch");
char *s = N_("ID/Password Settings");
char *s = N_("ID:");
char *s = N_("Image Compression Optimization:");
char *s = N_("Image Refinement:");
char *s = N_("Increase Print Speed for Forms:");
char *s = N_("Insert Interleaf Sheets:");
char *s = N_("Job Accounting");
char *s = N_("Landscape");
char *s = N_("Line Control:");
char *s = N_("Line Refinement:");
char *s = N_("Long Edge:");
char *s = N_("Manual Correction");
char *s = N_("Manual Setting");
char *s = N_("Matching Method:");
char *s = N_("Name Setting");
char *s = N_("Name of Data to Hold");
char *s = N_("Name: ");
char *s = N_("Number of Colors:");
char *s = N_("Number of Copies for Offset:  ");
char *s = N_("OK");
char *s = N_("Offset");
char *s = N_("Orientation");
char *s = N_("Output Adjustment Mode:");
char *s = N_("Output Method:");
char *s = N_("Output Options:");
char *s = N_("Page Layout");
char *s = N_("Page Size:");
char *s = N_("Paper Folding Unit");
char *s = N_("Paper Output:");
char *s = N_("Paper Source");
char *s = N_("Paper Source  ");
char *s = N_("Paper Source Options:");
char *s = N_("Paper Source:");
char *s = N_("Paper Type");
char *s = N_("Paper Type:");
char *s = N_("Password:");
char *s = N_("Portrait");
char *s = N_("Print Style:");
char *s = N_("Print on Interleaf Sheets");
char *s = N_("Print on:");
char *s = N_("Professional Puncher-C1");
char *s = N_("Profile Settings");
char *s = N_("Profile Settings...");
char *s = N_("Puncher Unit");
char *s = N_("Quality");
char *s = N_("RGB");
char *s = N_("Resolution:");
char *s = N_("Restore Defaults");
char *s = N_("Reverse Landscape");
char *s = N_("Reverse Portrait");
char *s = N_("Rotate");
char *s = N_("Saddle Finisher-G1");
char *s = N_("Saddle Stitch Setting:");
char *s = N_("Secure Watermark Function of Device");
char *s = N_("Secured Print Authentication:");
char *s = N_("Secured Print Settings");
char *s = N_("Select by");
char *s = N_("Set Back Cover");
char *s = N_("Set Front Cover");
char *s = N_("Settings...");
char *s = N_("Sharpness (Photo):");
char *s = N_("Sharpness:");
char *s = N_("Shift the Position to Start Printing");
char *s = N_("Short Edge:");
char *s = N_("Small-size Curl Adjustment:");
char *s = N_("Source Profile:");
char *s = N_("Special Print Adjustment A:");
char *s = N_("Special Print Adjustment B:");
char *s = N_("Special Print Adjustment C:");
char *s = N_("Special Print Mode:");
char *s = N_("Special Print Mode: ");
char *s = N_("Special Settings 1:");
char *s = N_("Special Smoothing Mode:");
char *s = N_("Staple");
char *s = N_("Staple Position:");
char *s = N_("Start:");
char *s = N_("Starting Number:");
char *s = N_("Store Destination");
char *s = N_("Toner Density:");
char *s = N_("Toner Save:");
char *s = N_("Toner Volume Adjustment:");
char *s = N_("Transparency Printing:");
char *s = N_("Trim Width:");
char *s = N_("Trimmer");
char *s = N_("Use Creep (Displacement) Correction");
char *s = N_("Use Document Insertion Unit");
char *s = N_("Use File Name");
char *s = N_("Use Secure Watermark Function of Device");
char *s = N_("User Inboxes:");
char *s = N_("User Name:");
char *s = N_("Width Adjustment:");
char *s = N_("mm (-10.3 to 10.2)");
char *s = N_("mm (-50 to 50)");
char *s = N_("mm (0 to 30)");
char *s = N_("mm (0.00 to 10.00)");

==> cndrvcups-lb-3.40-1.tar.gz: cndrvcups-lb-3.40/cngplp/gladestr.h <==
/* xgettext:no-c-format */
char *s = N_("(0 to 200)%");
char *s = N_("(1 to 10000)");
char *s = N_("(1 to 9999)");
char *s = N_("(1 to 9999) ");
char *s = N_("(1 to 9999999)");
char *s = N_("(Max. 32 characters)");
char *s = N_("*");
char *s = N_("0 to 99");
char *s = N_("Adjust Toner Volume Used for Color Printing:");
char *s = N_("Adjust Trim Width by");
char *s = N_("Advanced Settings");
char *s = N_("Advanced Settings...");
char *s = N_("Advanced Smoothing:");
char *s = N_("After Printing");
char *s = N_("Apply Device Settings");
char *s = N_("Automatic Correction");
char *s = N_("B & W Halftones:");
char *s = N_("Back Side");
char *s = N_("Banner");
char *s = N_("Before Printing");
char *s = N_("Before and After Printing");
char *s = N_("Binding Location:");
char *s = N_("Book Opening:");
char *s = N_("Booklet...");
char *s = N_("Brightness and Gamma");
char *s = N_("Brightness:");
char *s = N_("Cancel");
char *s = N_("Color Halftones:");
char *s = N_("Color Mode:");
char *s = N_("Color to Use with Black:");
char *s = N_("Copy Set Numbering");
char *s = N_("Correction Width:");
char *s = N_("Data Name");
char *s = N_("Dept. ID Management Authentication:");
char *s = N_("Detailed Settings for Booklet");
char *s = N_("Device Setting ");
char *s = N_("Device Settings");
char *s = N_("Displacement Correction Method");
char *s = N_("Do Not Auto Eject");
char *s = N_("Do Not Use Job Accounting When B&W Printing");
char *s = N_("Document Insertion Unit");
char *s = N_("Document Name:");
char *s = N_("Draft Mode:");
char *s = N_("End:");
char *s = N_("Enter Name");
char *s = N_("Face Up/Face Down:");
char *s = N_("Feed A5 from Short Edge:");
char *s = N_("Finishing");
char *s = N_("Finishing Details");
char *s = N_("Finishing Details...");
char *s = N_("Finishing:");
char *s = N_("Fold Details:");
char *s = N_("Fold:");
char *s = N_("Front Side");
char *s = N_("Front/Back Cover Settings");
char *s = N_("Front/Back Cover Settings...");
char *s = N_("Gamma:");
char *s = N_("General");
char *s = N_("Glossy Plain Paper Processing:");
char *s = N_("Gutter Settings");
char *s = N_("Gutter...");
char *s = N_("Gutter:");
char *s = N_("Hole Punch");
char *s = N_("ID/Password Settings");
char *s = N_("ID:");
char *s = N_("Image Compression Optimization:");
char *s = N_("Image Refinement:");
char *s = N_("Image Special Process:");
char *s = N_("Increase Print Speed for Forms:");
char *s = N_("Insert Interleaf Sheets:");
char *s = N_("Job Accounting");
char *s = N_("Landscape");
char *s = N_("Line Control:");
char *s = N_("Line Refinement:");
char *s = N_("Long Edge:");
char *s = N_("Manual Correction");
char *s = N_("Manual Setting");
char *s = N_("Matching Method:");
char *s = N_("Name Setting");
char *s = N_("Name of Data to Hold");
char *s = N_("Name:");
char *s = N_("Number of Colors:");
char *s = N_("Number of Copies for Offset:");
char *s = N_("Number of Copies to Stack:");
char *s = N_("OK");
char *s = N_("Offset");
char *s = N_("Orientation");
char *s = N_("Output Adjustment Mode:");
char *s = N_("Output Method:");
char *s = N_("Output Options:");
char *s = N_("Page Layout");
char *s = N_("Page Size:");
char *s = N_("Paper Folding Unit");
char *s = N_("Paper Output:");
char *s = N_("Paper Source");
char *s = N_("Paper Source ");
char *s = N_("Paper Source Options:");
char *s = N_("Paper Source:");
char *s = N_("Paper Type");
char *s = N_("Paper Type:");
char *s = N_("Password:");
char *s = N_("Portrait");
char *s = N_("Print Style:");
char *s = N_("Print on Interleaf Sheets");
char *s = N_("Print on:");
char *s = N_("Printer Default");
char *s = N_("Professional Puncher-C1");
char *s = N_("Profile Settings");
char *s = N_("Profile Settings...");
char *s = N_("Puncher Unit");
char *s = N_("Quality");
char *s = N_("RGB");
char *s = N_("Resolution:");
char *s = N_("Restore Defaults");
char *s = N_("Reverse Landscape");
char *s = N_("Reverse Portrait");
char *s = N_("Rotate");
char *s = N_("Saddle Finisher-G1");
char *s = N_("Saddle Stitch Setting:");
char *s = N_("Secure Watermark Function of Device");
char *s = N_("Secured Print Authentication:");
char *s = N_("Secured Print Settings");
char *s = N_("Select by");
char *s = N_("Set Back Cover");
char *s = N_("Set Front Cover");
char *s = N_("Settings...");
char *s = N_("Sharpness (Photo):");
char *s = N_("Sharpness:");
char *s = N_("Sheets per Set:");
char *s = N_("Shift the Position to Start Printing");
char *s = N_("Short Edge:");
char *s = N_("Small-size Curl Adjustment:");
char *s = N_("Source Profile:");
char *s = N_("Special Print Adjustment A:");
char *s = N_("Special Print Adjustment B:");
char *s = N_("Special Print Adjustment C:");
char *s = N_("Special Print Mode:");
char *s = N_("Special Print Mode: ");
char *s = N_("Special Settings 1:");
char *s = N_("Special Smoothing Mode:");
char *s = N_("Specify Number of Copies to Stack");
char *s = N_("Stack Details");
char *s = N_("Stack Details...");
char *s = N_("Staple");
char *s = N_("Staple Position:");
char *s = N_("Start:");
char *s = N_("Starting Number:");
char *s = N_("Store Destination");
char *s = N_("Timing of Auto Eject from Stacker");
char *s = N_("Toner Density:");
char *s = N_("Toner Save:");
char *s = N_("Toner Volume Adjustment:");
char *s = N_("Transparency Printing:");
char *s = N_("Trim Width:");
char *s = N_("Trimmer");
char *s = N_("Use Creep (Displacement) Correction");
char *s = N_("Use Document Insertion Unit");
char *s = N_("Use File Name");
char *s = N_("Use Secure Watermark Function of Device");
char *s = N_("Use User Authentication Function");
char *s = N_("User Inboxes:");
char *s = N_("User Name/Password Settings");
char *s = N_("User Name:");
char *s = N_("Width Adjustment:");
char *s = N_("mm (-10.3 to 10.2)");
char *s = N_("mm (-50 to 50)");
char *s = N_("mm (0 to 30)");
char *s = N_("mm (0.00 to 10.00)");
